summaryrefslogtreecommitdiffstats
path: root/cpukit/libnetworking/rtems/tftp.h
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/libnetworking/rtems/tftp.h')
-rw-r--r--cpukit/libnetworking/rtems/tftp.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/cpukit/libnetworking/rtems/tftp.h b/cpukit/libnetworking/rtems/tftp.h
index b6a1bb5e8f..7fb977ffa0 100644
--- a/cpukit/libnetworking/rtems/tftp.h
+++ b/cpukit/libnetworking/rtems/tftp.h
@@ -20,7 +20,8 @@
* To open `/bootfiles/image' on `hostname' for reading:
* fd = open ("/TFTP/hostname/bootfiles/image", O_RDONLY);
*
* The `hostname' must be four dot-separated decimal values.
*/
#ifndef _RTEMS_TFTP_H
@@ -33,6 +34,11 @@ extern "C" {
#include <rtems/libio.h>
/*
+ * Filesystem Mount table entry.
+ */
+int rtems_tftpfs_initialize(rtems_filesystem_mount_table_entry_t *temp_mt_entry);
+
+/*
* Filesystem initialization routine
*/
@@ -20,7 +20,8 @@
* fd = open ("/TFTP/hostname/bootfiles/image", O_RDONLY);
*
- * The `hostname' must be four dot-separated decimal values.
+ * The 'TFTP' is the mount path and the `hostname' must be four dot-separated
+ * decimal values.
*/
#ifndef _RTEMS_TFTP_H